Lazy Load Enabled With FadeIn Effect

# Lazy Load Plugin for jQuery

Blog Projects

## Plugin enabled with fadein effect

Images below the fold (the ones lower than window bottom) are not loaded. When scrolling down they are loaded when needed. Images appear using fadeIn effect. Empty cache and shift-reload to test again. Compare this to page where plugin is without effects.

    $("img.lazy").lazyload({
        effect : "fadeIn"
    });

    <img class="lazy" data-original="img/example.jpg" width="765" height="574">